@@ -5,6 +5,7 @@
 #'
 #' @param sdp vector of sdp values
 #' @param haplos letter codes for haplotypes (required)
+#' @param symmetric make patterns symmetric if \code{TRUE}
 #'
 #' @return vector of letter patterns
 #'
@@ -13,8 +14,12 @@
 #'
 #' @importFrom assertthat assert_that
 #' 
-sdp_to_pattern <- function(sdp, haplos) {
+sdp_to_pattern <- function(sdp, haplos, symmetric = TRUE) {
   assertthat::assert_that(!missing(haplos))
+  if(symmetric) {
+    numsdp <- 2 ^ length(haplos)
+    sdp <- ifelse(sdp < numsdp / 2, sdp, numsdp - sdp - 1)
+  }
   sapply(sdp, function(x, haplos) {
     ref <- as.logical(intToBits(x)[seq_along(haplos)])
     paste(paste(haplos[!ref], collapse = ""),
